@@ -1,9 +1,11 @@
+# -*- coding:utf-8  -*-
+
 import sys
 if sys.version_info[0] == 2:
     import tkFileDialog as tk
-elif sys.version_info[0] == 3 and sys.version_info[1] < 6:
+elif sys.version_info[0] == 3 and sys.version_info[1] < 4:
     import filedialog as tk
-elif sys.version_info[0] == 3 and sys.version_info[1] >= 6:
+elif sys.version_info[0] == 3 and sys.version_info[1] >= 4:
     import tkinter.filedialog as tk
 else:
     raise SystemExit('This Python version is not supported by the current version of Python-Extension.')
@@ -18,6 +20,7 @@ word = {
         'again',
         'all',
         'alpha',
+        'alphabet'
         'am',
         'an',
         'ant',
@@ -48,6 +51,7 @@ word = {
         'basketball',
         'beach',
         'bit',
+        'bin',
         'boom',
         'bring',
         'bridge',
@@ -60,6 +64,7 @@ word = {
         'cake',
         'case',
         'cash',
+        'caugh',
         'canvas',
         'cabbage',
         'celebrate',
@@ -70,16 +75,38 @@ word = {
         'd',
         'data',
         'date',
-        'dance'
+        'dance',
+        'dancer',
         'danger',
         'dangeons',
-        ''
+        'desktop',
+        'December',
+        'dist',
+        'dictionary'
+        'document',
+        'duck',
         ],
     'e' : [
-        'e'
+        'e',
+        'egg',
+        'else',
+        'entry',
+        'entrance',
+        'explore',
+        'explorer',
         ],
     'f' : [
-        'f'
+        'f',
+        'float',
+        'flow',
+        'fade',
+        'fuck',
+        'fucking',
+        'find',
+        'found',
+        'founder',
+        'fix',
+        'fat'
         ],
     'g' : [
         'g'
