@@ -1,4 +1,4 @@
-# -*- coding=utf-8 -*-
+# -*- coding:utf-8  -*-
 
 def opensource(module='tkextension'):
     if module == 'tkextension' or module == '__init__':
@@ -6,38 +6,33 @@ def opensource(module='tkextension'):
         get = file.read()
         file.close()
         return get
-    elif module == 'about':
-        file = open('about.py')
-        get = file.read()
-        file.close()
-        return get
-    elif module == 'canvas':
-        file = open('canvas.py')
-        get = file.read()
-        file.close()
-        return get
     elif module == 'blackboard':
         file = open('blackboard.py')
         get = file.read()
         file.close()
         return get
+    elif module == 'test':
+        file = open('test.py')
+        get = file.read()
+        file.close()
+        return get
     elif module == 'timer':
         file = open('timer.py')
         get = file.read()
         file.close()
         return get
     elif module == 'tix':
-        file = open('tix.py')
+        file = open('tix/__init__.py')
         get = file.read()
         file.close()
         return get
-    elif module == 'turtle' or module == 'turtledrawer':
-        file = open('tuterdrawer.py')
+    elif module == 'tix.filedialog' or module == 'filedialog':
+        file = open('tix/filedialog.py')
         get = file.read()
         file.close()
         return get
-    elif module == 'value':
-        file = open('value.py')
+    elif module == 'turtledrawer':
+        file = open('turtledrawer.py')
         get = file.read()
         file.close()
         return get
